==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/UserLockoutSettings.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserLockoutSettings
 */
@JsonPropertyOrder({ UserLockoutSettings.JSON_PROPERTY_PREVENT_BRUTE_FORCE_LOCKOUT_FROM_UNKNOWN_DEVICES })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserLockoutSettings implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_PREVENT_BRUTE_FORCE_LOCKOUT_FROM_UNKNOWN_DEVICES = "preventBruteForceLockoutFromUnknownDevices";
    private Boolean preventBruteForceLockoutFromUnknownDevices = false;

    public UserLockoutSettings() {
    }

    public UserLockoutSettings preventBruteForceLockoutFromUnknownDevices(
            Boolean preventBruteForceLockoutFromUnknownDevices) {

        this.preventBruteForceLockoutFromUnknownDevices = preventBruteForceLockoutFromUnknownDevices;
        return this;
    }

    /**
     * Prevents brute-force lockout from unknown devices for the password authenticator.
     *
     * @return preventBruteForceLockoutFromUnknownDevices
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Prevents brute-force lockout from unknown devices for the password authenticator.")
    @JsonProperty(JSON_PROPERTY_PREVENT_BRUTE_FORCE_LOCKOUT_FROM_UNKNOWN_DEVICES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getPreventBruteForceLockoutFromUnknownDevices() {
        return preventBruteForceLockoutFromUnknownDevices;
    }

    @JsonProperty(JSON_PROPERTY_PREVENT_BRUTE_FORCE_LOCKOUT_FROM_UNKNOWN_DEVICES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPreventBruteForceLockoutFromUnknownDevices(Boolean preventBruteForceLockoutFromUnknownDevices) {
        this.preventBruteForceLockoutFromUnknownDevices = preventBruteForceLockoutFromUnknownDevices;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserLockoutSettings userLockoutSettings = (UserLockoutSettings) o;
        return Objects.equals(this.preventBruteForceLockoutFromUnknownDevices,
                userLockoutSettings.preventBruteForceLockoutFromUnknownDevices);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(preventBruteForceLockoutFromUnknownDevices);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserLockoutSettings {\n");
        sb.append("    preventBruteForceLockoutFromUnknownDevices: ")
                .append(toIndentedString(preventBruteForceLockoutFromUnknownDevices)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/UserLockoutSettings.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserLockoutSettings
 */
@JsonPropertyOrder({ UserLockoutSettings.JSON_PROPERTY_PREVENT_BRUTE_FORCE_LOCKOUT_FROM_UNKNOWN_DEVICES })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class UserLockoutSettings implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_PREVENT_BRUTE_FORCE_LOCKOUT_FROM_UNKNOWN_DEVICES = "preventBruteForceLockoutFromUnknownDevices";
    private Boolean preventBruteForceLockoutFromUnknownDevices = false;

    public UserLockoutSettings() {
    }

    public UserLockoutSettings preventBruteForceLockoutFromUnknownDevices(
            Boolean preventBruteForceLockoutFromUnknownDevices) {

        this.preventBruteForceLockoutFromUnknownDevices = preventBruteForceLockoutFromUnknownDevices;
        return this;
    }

    /**
     * Prevents brute-force lockout from unknown devices for the password authenticator.
     *
     * @return preventBruteForceLockoutFromUnknownDevices
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Prevents brute-force lockout from unknown devices for the password authenticator.")
    @JsonProperty(JSON_PROPERTY_PREVENT_BRUTE_FORCE_LOCKOUT_FROM_UNKNOWN_DEVICES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getPreventBruteForceLockoutFromUnknownDevices() {
        return preventBruteForceLockoutFromUnknownDevices;
    }

    @JsonProperty(JSON_PROPERTY_PREVENT_BRUTE_FORCE_LOCKOUT_FROM_UNKNOWN_DEVICES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPreventBruteForceLockoutFromUnknownDevices(Boolean preventBruteForceLockoutFromUnknownDevices) {
        this.preventBruteForceLockoutFromUnknownDevices = preventBruteForceLockoutFromUnknownDevices;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserLockoutSettings userLockoutSettings = (UserLockoutSettings) o;
        return Objects.equals(this.preventBruteForceLockoutFromUnknownDevices,
                userLockoutSettings.preventBruteForceLockoutFromUnknownDevices);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(preventBruteForceLockoutFromUnknownDevices);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserLockoutSettings {\n");
        sb.append("    preventBruteForceLockoutFromUnknownDevices: ")
                .append(toIndentedString(preventBruteForceLockoutFromUnknownDevices)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
